# YouTube-Scraping-API
An easy-to-use YouTube API, without any kind of quota, and download any videos on youtube as much as you like. <br />
I'm still working on it, so stay tuned for more updates to come.


## Documentation
https://ytsa.thecodeblog.net


## Versions

### 0.0.1 (deleted)
- Not an official release (careless bug found)

### 0.0.2
- Freshly uploaded this package to PyPi

### 0.0.3/0.0.4/0.0.5
- Updated README.md

### 0.1.0
- Video caption feature added

### 0.1.1
- Updated README.md

### 0.1.2
- minor bug fixed on video download

### 1.0.0
- Major code refactoring
- Channel feature completed
- Query suggestions feature added
- Docstring for every methods and classes added
- Documentation added

### 1.1.0
- Major bug fixed
- Feature to scrape search query suggestions added

### 1.1.1
- Version log updated

### 1.1.2
- Minor bug fixed
- User can now parse raw metadata from channel object

### 1.1.3
- Minor bug fixed
- Proxies added

### 1.1.4
- `get_all_filters` function added
